----------------------------------------------------
-- Delta method needs to compute the E1 and highpass
-- series for Soil Temp and then Subtract
----------------------------------------------------

use SoilTempKL;
go

---------------------------------------------------
-- Drop tables
--------------------------------------------------
drop table #c1
drop table #c7
drop table #c14
drop table delta
drop table smooth
drop table coef

-----------------------------------------------------
-- create the coeff table with the projection values
------------------------------------------------------
create table coef
(
	sensorid smallint not null,
	day int not null,
	e1 real not null,
	e2 real not null,
	e3 real not null,
	e4 real not null,
	primary key (sensorid, day)
)

--------------------------------------------------------
-- Populate the coeff table with projection values
-- NOTE : CHANGE THE LOCATION !
--------------------------------------------------------
BULK INSERT coef
   FROM '..\PCA\PCA_output\coef_ST.csv'
   WITH 
      (
		 TABLOCK,
		 ROWS_PER_BATCH=10000,
         FIELDTERMINATOR =',',
         ROWTERMINATOR ='\n'
      )

select 	day, 
	avg(e1) e1, 
	avg(e2) e2, 
	avg(e3) e3,
	avg(e4) e4
into #c1
from coef c
group by day

-------------------------------------------------
-- Days table
--------------------------------------------------
drop table days
select distinct day into days from coef order by day

---------------------------------------------------
-- E1 series averaged across all sensors.
---------------------------------------------------
select day, e1
from #c1
order by day

-------------------------------------------------------
-- Create the Highpass Series
-------------------------------------------------------
-------------------------------------------------
-- Remove the seasonal drift from the E1 series
-- by running a highpass filter
-- Highpass = Original - Lowpass (Smooth)
-- Kernel of Smooth filter is 7
------------------------------------------------
declare @kernel int
set @kernel = 3

select  d.day, 
	avg(a.e1) e1, 
	avg(a.e2) e2, 
	avg(a.e3) e3,
	avg(a.e4) e4
into #c7
from #c1 a, days d
where a.day between d.day-@kernel and d.day+@kernel
group by d.day
--
select  d.day, 
	avg(a.e1) e1, 
	avg(a.e2) e2, 
	avg(a.e3) e3,
	avg(a.e4) e4
into #c14
from #c7 a, days d
where a.day between d.day-@kernel and d.day+@kernel
group by d.day
--
select  d.day, 
	avg(a.e1) e1, 
	avg(a.e2) e2, 
	avg(a.e3) e3,
	avg(a.e4) e4
into smooth
from #c14 a, days d
where a.day between d.day-@kernel and d.day+@kernel
group by d.day

-----------------------------------
-- Compute the difference
-----------------------------------
drop table highpass
select 
 a.day,
(a.e1 - b.e1) as d1,
(a.e2 - b.e2) as d2,
(a.e3 - b.e3) as d3,
(a.e4 - b.e4) as d4
into highpass
from #c1 a, smooth b
where a.day = b.day

---------------------------------------
-- Create the Delta Series
----------------------------------------
-- Box Temp e1
use BoxTempKL
drop table #bt_d1
select day, d1 into #bt_d1 from highpass order by day

-- Soil Temp d1
use SoilTempKL
drop table #st_d1
select day, d1 into #st_d1 from highpass order by day

-- Diff_d1
select a.day, (a.d1 - b.d1) as diff_d1
from #bt_d1 a, #st_d1 b
where a.day = b.day
order by a.day
